mathtools.integer_equivalent_number_to_integer
==============================================

.. autofunction:: abjad.tools.mathtools.integer_equivalent_number_to_integer.integer_equivalent_number_to_integer
